@@ -1,7 +1,8 @@
 /* files.c -- file-related functions for makeinfo.
-   $Id: files.c,v 1.10 2002/01/16 15:52:45 karl Exp $
+   $Id: files.c,v 1.3 2003/03/06 14:05:30 karl Exp $
 
-   Copyright (C) 1998, 99, 2000, 01, 02 Free Software Foundation, Inc.
+   Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003 Free Software
+   Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -82,7 +83,7 @@ extract_colon_unit (string, index)
    When found, return the stat () info for FILENAME in FINFO.
    If PATH is NULL, only the current directory is searched.
    If the file could not be found, return a NULL pointer. */
-static char *
+char *
 get_file_info_in_path (filename, path, finfo)
      char *filename, *path;
      struct stat *finfo;
@@ -322,9 +323,7 @@ filename_part (filename)
 #ifdef REMOVE_OUTPUT_EXTENSIONS
   /* See if there is an extension to remove.  If so, remove it. */
   {
-    char *temp;
-
-    temp = strrchr (basename, '.');
+    char *temp = strrchr (basename, '.');
     if (temp)
       *temp = 0;
   }
