@@ -1,7 +1,8 @@
 /* node.c -- nodes for Texinfo.
-   $Id: node.c,v 1.5 2002/11/05 03:04:26 karl Exp $
+   $Id: node.c,v 1.12 2003/05/01 00:30:07 karl Exp $
 
-   Copyright (C) 1998, 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003 Free Software
+   Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -483,7 +484,7 @@ set_current_output_filename (fname)
 /* The order is: nodename, nextnode, prevnode, upnode.
    If all of the NEXT, PREV, and UP fields are empty, they are defaulted.
    You must follow a node command which has those fields defaulted
-   with a sectioning command (e.g. @chapter) giving the "level" of that node.
+   with a sectioning command (e.g., @chapter) giving the "level" of that node.
    It is an error not to do so.
    The defaults come from the menu in this node's parent. */
 void
@@ -594,7 +595,7 @@ cm_node ()
   filling_enabled = indented_fill = 0;
   if (!html || (html && splitting))
     current_footnote_number = 1;
-  
+
   if (verbose_mode)
     printf (_("Formatting node %s...\n"), node);
 
@@ -608,7 +609,7 @@ cm_node ()
       xml_begin_node ();
       if (!docbook)
 	{
-	  xml_insert_element (NODENAME, START);      
+	  xml_insert_element (NODENAME, START);
 	  if (macro_expansion_output_stream && !executing_string)
 	    me_execute_string (node);
 	  else
@@ -657,7 +658,7 @@ cm_node ()
               }
 
           line_error
-            (_("Node `%s' requires a sectioning command (e.g. %c%s)"),
+            (_("Node `%s' requires a sectioning command (e.g., %c%s)"),
              node, COMMAND_PREFIX, polite_section_name);
         }
       else
@@ -923,7 +924,7 @@ cm_node ()
           add_word ("<div class=\"node\">\n");
           /* The <p> avoids the links area running on with old Lynxen. */
           add_word_args ("<p>%s\n", splitting ? "" : "<hr>");
-          add_word_args ("%s<a name=\"", _("Node:"));
+          add_word_args ("%s%s<a name=\"", _("Node:"), "&nbsp;");
           tem = expand_node_name (node);
           add_anchor_name (tem, 0);
           add_word_args ("\">%s</a>", tem);
@@ -934,6 +935,7 @@ cm_node ()
               tem = expansion (next, 0);
 	      add_word (",\n");
 	      add_word (_("Next:"));
+              add_word ("&nbsp;");
 	      add_word ("<a rel=\"next\" accesskey=\"n\" href=\"");
 	      add_anchor_name (tem, 1);
 	      add_word_args ("\">%s</a>", tem);
@@ -944,6 +946,7 @@ cm_node ()
               tem = expansion (prev, 0);
 	      add_word (",\n");
 	      add_word (_("Previous:"));
+              add_word ("&nbsp;");
 	      add_word ("<a rel=\"previous\" accesskey=\"p\" href=\"");
 	      add_anchor_name (tem, 1);
 	      add_word_args ("\">%s</a>", tem);
@@ -954,6 +957,7 @@ cm_node ()
               tem = expansion (up, 0);
 	      add_word (",\n");
 	      add_word (_("Up:"));
+              add_word ("&nbsp;");
 	      add_word ("<a rel=\"up\" accesskey=\"u\" href=\"");
 	      add_anchor_name (tem, 1);
 	      add_word_args ("\">%s</a>", tem);
@@ -978,7 +982,7 @@ cm_node ()
       if (prev)
 	{
 	  xml_insert_element (NODEPREV, START);
-	  execute_string ("%s", prev);	    
+	  execute_string ("%s", prev);
 	  xml_insert_element (NODEPREV, END);
 	}
       if (up)
@@ -1041,6 +1045,9 @@ cm_anchor (arg)
   /* Parse the anchor text.  */
   anchor = get_xref_token (1);
 
+  /* Force all versions of "top" to be "Top". */
+  normalize_node_name (anchor);
+
   /* In HTML mode, need to actually produce some output.  */
   if (html)
     {
@@ -1281,7 +1288,7 @@ validate (tag, line, label)
   if (!result)
     {
       line_number = line;
-      line_error (_("%s reference to nonexistent node `%s'"), label, tag);
+      line_error (_("%s reference to nonexistent node `%s' (perhaps incorrect sectioning?)"), label, tag);
       return 0;
     }
   result->touched++;
@@ -1291,7 +1298,7 @@ validate (tag, line, label)
 /* The strings here are followed in the message by `reference to...' in
    the `validate' routine.  They are only used in messages, thus are
    translated.  */
-static char *
+static const char *
 reftype_type_string (type)
      enum reftype type;
 {
@@ -1384,7 +1391,7 @@ validate_file (tag_table)
                 }
               if (you_lose)
                 {
-                  line_error (_("Next field of node `%s' not pointed to"),
+                  line_error (_("Next field of node `%s' not pointed to (perhaps incorrect sectioning?)"),
                               tags->node);
                   file_line_error (temp_tag->filename, temp_tag->line_no,
 				   _("This node (%s) has the bad Prev"),
@@ -1458,7 +1465,7 @@ validate_file (tag_table)
       if (!tags->up
           && !(tags->flags & TAG_FLAG_ANCHOR)
           && strcasecmp (tags->node, "Top") != 0)
-        line_error (_("`%s' has no Up field"), tags->node);
+        line_error (_("`%s' has no Up field (perhaps incorrect sectioning?)"), tags->node);
       else if (tags->up)
         {
           int valid_p = validate (tags->up, tags->line_no, _("Up"));
@@ -1597,7 +1604,7 @@ last_node_p (tags)
         break;
       }
   }
-  
+
   return last;
 }
 
@@ -1627,8 +1634,8 @@ split_file (filename, size)
   if (size == 0)
     size = DEFAULT_SPLIT_SIZE;
 
-  if ((stat (filename, &fileinfo) != 0) ||
-      (((long) fileinfo.st_size) < SPLIT_SIZE_THRESHOLD))
+  if ((stat (filename, &fileinfo) != 0)
+      || (((long) fileinfo.st_size) < size))
     return;
   file_size = (long) fileinfo.st_size;
 
@@ -1655,6 +1662,10 @@ split_file (filename, size)
     TAG_ENTRY *tags = tag_table;
     char *indirect_info = NULL;
 
+    /* Maybe we want a Local Variables section.  */
+    char *trailer = info_trailer ();
+    int trailer_len = trailer ? strlen (trailer) : 0;
+
     /* Remember the `header' of this file.  The first tag in the file is
        the bottom of the header; the top of the file is the start. */
     the_header = xmalloc (1 + (header_size = tags->position));
@@ -1776,7 +1787,9 @@ split_file (filename, size)
                       || write (fd, the_header, header_size) != header_size
                       || write (fd, the_file + file_top, file_bot - file_top)
                          != (file_bot - file_top)
-                      || (close (fd)) < 0)
+                      || (trailer_len
+                          && write (fd, trailer, trailer_len) != trailer_len)
+                      || close (fd) < 0)
                     {
                       perror (split_filename);
                       if (fd != -1)
@@ -1821,7 +1834,16 @@ split_file (filename, size)
       /* Inhibit newlines. */
       paragraph_is_open = 0;
 
+      /* Write the indirect tag table.  */
       write_tag_table_indirect ();
+
+      /* preserve local variables in info output.  */
+      if (trailer)
+        {
+          insert_string (trailer);
+          free (trailer);
+        }
+
       fclose (output_stream);
       free (the_header);
       free (the_file);
