@@ -1,7 +1,7 @@
 /* install-info -- create Info directory entry(ies) for an Info file.
-   $Id: install-info.c,v 1.4 2002/11/05 19:32:33 karl Exp $
+   $Id: install-info.c,v 1.9 2003/05/19 13:10:59 karl Exp $
 
-   Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002 Free Software
+   Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003 Free Software
    Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
@@ -165,33 +165,6 @@ fatal (s1, s2, s3)
   xexit (1);
 }
 
-/* Memory allocation and string operations.  */
-
-/* Like malloc but get fatal error if memory is exhausted.  */
-void *
-xmalloc (size)
-     unsigned int size;
-{
-  extern void *malloc ();
-  void *result = malloc (size);
-  if (result == NULL)
-    fatal (_("virtual memory exhausted"), 0, 0);
-  return result;
-}
-
-/* Like realloc but get fatal error if memory is exhausted.  */
-void *
-xrealloc (obj, size)
-     void *obj;
-     unsigned int size;
-{
-  extern void *realloc ();
-  void *result = realloc (obj, size);
-  if (result == NULL)
-    fatal (_("virtual memory exhausted"), 0, 0);
-  return result;
-}
-
 /* Return a newly-allocated string
    whose contents concatenate those of S1, S2, S3.  */
 char *
@@ -462,8 +435,10 @@ The first time you invoke Info you start off looking at this node.\n\
   In Emacs, you can click mouse button 2 on a menu item or cross reference\n\
   to select it.\n\
 \n\
-* Menu:\n\
-"), "File: dir,\tNode: Top"); /* This part must not be translated.  */
+%s\n\
+"), "File: dir,\tNode: Top",  /* These keywords must not be translated.  */
+    "* Menu:"
+);
           if (fclose (f) < 0)
             pfatal_with_name (dirfile);
         }
@@ -1251,7 +1226,7 @@ main (argc, argv)
 There is NO warranty.  You may redistribute this software\n\
 under the terms of the GNU General Public License.\n\
 For more information about these matters, see the files named COPYING.\n"),
-                  "2002");
+                  "2003");
           xexit (0);
 
         default:
@@ -1395,7 +1370,7 @@ For more information about these matters, see the files named COPYING.\n"),
                       }
                     if (!spec || spec == entry->entry_sections_tail)
                       continue;
-                    
+
                     /* Subtract one because dir_lines is zero-based,
                        but the `end_line' and `start_line' members are
                        one-based.  */
@@ -1440,6 +1415,7 @@ For more information about these matters, see the files named COPYING.\n"),
                   entries_to_add, input_sections, compression_program);
 
   xexit (0);
+  return 0; /* Avoid bogus warnings.  */
 }
 
 /* Divide the text at DATA (of SIZE bytes) into lines.
